@@ -112,9 +112,10 @@ class AlbumView(LazyLoadingView, TracksView, ViewController):
 
     def _on_map(self, widget):
         """
-            Connect signals and set active ids
+            Set initial state and connect signals
             @param widget as Gtk.Widget
         """
+        LazyLoadingView._on_map(self, widget)
         self._responsive_widget.set_margin_top(
             self.__banner.default_height + 15)
         App().window.emit("show-can-go-back", True)
@@ -126,12 +127,19 @@ class AlbumView(LazyLoadingView, TracksView, ViewController):
         App().settings.set_value("state-three-ids",
                                  GLib.Variant("ai", [self._album.id]))
 
+    def _on_unmap(self, widget):
+        """
+            Disconnect signals
+            @param widget as Gtk.Widget
+        """
+        LazyLoadingView._on_unmap(self, widget)
+
     def _on_tracks_populated(self, disc_number):
         """
             Emit populated signal
             @param disc_number as int
         """
-        if TracksView.get_populated(self) and not App().window.is_adaptive:
+        if TracksView.get_populated(self):
             from lollypop.view_albums_box import AlbumsBoxView
             for artist_id in self.__artist_ids:
                 if artist_id == Type.COMPILATIONS:
@@ -163,6 +171,14 @@ class AlbumView(LazyLoadingView, TracksView, ViewController):
         else:
             TracksView.populate(self)
 
-#######################
-# PRIVATE             #
-#######################
+    def _on_adaptive_changed(self, window, status):
+        """
+            Update banner style
+            @param window as Window
+            @param status as bool
+        """
+        if status:
+            view_type = self._view_type | ViewType.SMALL
+        else:
+            view_type = self._view_type & ~ViewType.SMALL
+        self.__banner.set_view_type(view_type)
