@@ -137,19 +137,21 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
         ArtistAlbumsView._on_current_changed(self, player)
         self.__update_jump_button()
 
-    def _on_populated(self, widget):
+    def _on_populated(self, widget, idle_id):
         """
             Set jump button state
             @param widget as AlbumDetailedWidget
+            @param idle_id as int
         """
         self.__update_jump_button()
-        ArtistAlbumsView._on_populated(self, widget)
+        ArtistAlbumsView._on_populated(self, widget, idle_id)
 
     def _on_map(self, widget):
         """
             Connect signals and set active ids
             @param widget as Gtk.Widget
         """
+        ArtistAlbumsView._on_map(self, widget)
         self.__on_album_changed(App().player)
         self.__art_signal_id = App().art.connect(
                                            "artist-artwork-changed",
@@ -175,6 +177,7 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
             Disconnect signals
             @param widget as Gtk.Widget
         """
+        ArtistAlbumsView._on_unmap(self, widget)
         if self.__art_signal_id is not None:
             App().art.disconnect(self.__art_signal_id)
             self.__art_signal_id = None
@@ -188,6 +191,18 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
             App().player.disconnect(self.__removed_signal_id)
             self.__removed_signal_id = None
 
+    def _on_adaptive_changed(self, window, status):
+        """
+            Update banner style
+            @param window as Window
+            @param status as bool
+        """
+        if status:
+            App().window.container.show_view(
+                self._genre_ids, self._artist_ids, True)
+            # Destroy after any animation
+            GLib.idle_add(self.destroy, priority=GLib.PRIORITY_LOW)
+
 #######################
 # PRIVATE             #
 #######################
